@@ -48,6 +48,7 @@
 #define AUTHORS "Q. Frank Xia"
 
 #include <stdio.h>
+#include <sys/types.h>
 #include "system.h"
 
 #if !defined UINT_FAST32_MAX && !defined uint_fast32_t
@@ -116,7 +117,6 @@ main (void)
 #else /* !CRCTAB */
 
 # include <getopt.h>
-# include <sys/types.h>
 # include "closeout.h"
 # include "long-options.h"
 # include "error.h"
@@ -288,7 +288,7 @@ Print CRC checksum and byte counts of each FILE.\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
-      puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
