@@ -36,6 +36,7 @@
 #include "argmatch.h"
 #include "error.h"
 #include "human.h"
+#include "posixver.h"
 #include "safe-read.h"
 #include "xstrtol.h"
 
@@ -285,17 +286,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 If the first character of N (the number of bytes or lines) is a `+',\n\
 print beginning with the Nth item from the start of each file, otherwise,\n\
 print the last N items in the file.  N may have a multiplier suffix:\n\
-b for 512, k for 1024, m for 1048576 (1 Meg).  \
-"), stdout);
-     fputs (_("\
-A first OPTION of -VALUE\n\
-is treated like -n VALUE unless VALUE has one of the [bkm] suffix\n\
-multipliers, in which case it is treated like -c VALUE.\n\
-"), stdout);
-     if (POSIX2_VERSION < 200112)
-       fputs (_("\
-A first option of +VALUE is treated like -+VALUE, but this usage is obsolete\n\
-and support for it will be withdrawn.\n\
+b for 512, k for 1024, m for 1048576 (1 Meg).\n\
 \n\
 "), stdout);
      fputs (_("\
@@ -309,9 +300,8 @@ track the actual name of the file, not the file descriptor (e.g., log\n\
 rotation).  Use --follow=name in that case.  That causes tail to track the\n\
 named file by reopening it periodically to see if it has been removed and\n\
 recreated by some other program.\n\
-\n\
 "), stdout);
-      puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -747,7 +737,7 @@ start_bytes (const char *pretty_filename, int fd, off_t n_bytes)
 
 /* Skip N_LINES lines at the start of file or pipe FD, and print
    any extra characters that were read beyond that.
-   Return 1 on error, 0 if ok.  */
+   Return 1 on error, 0 if ok, -1 if EOF.  */
 
 static int
 start_lines (const char *pretty_filename, int fd, long int n_lines)
@@ -756,6 +746,9 @@ start_lines (const char *pretty_filename, int fd, long int n_lines)
   int bytes_read = 0;
   int bytes_to_skip = 0;
 
+  if (n_lines == 0)
+    return 0;
+
   while (n_lines && (bytes_read = safe_read (fd, buffer, BUFSIZ)) > 0)
     {
       bytes_to_skip = 0;
@@ -763,16 +756,24 @@ start_lines (const char *pretty_filename, int fd, long int n_lines)
 	if (buffer[bytes_to_skip++] == '\n' && --n_lines == 0)
 	  break;
     }
+
+  /* EOF */
+  if (bytes_read == 0)
+    return -1;
+
+  /* error */
   if (bytes_read == -1)
     {
       error (0, errno, "%s", pretty_filename);
       return 1;
     }
-  else if (bytes_to_skip < bytes_read)
+
+  if (bytes_to_skip < bytes_read)
     {
       xwrite (STDOUT_FILENO, &buffer[bytes_to_skip],
 	      bytes_read - bytes_to_skip);
     }
+
   return 0;
 }
 
@@ -961,7 +962,8 @@ tail_forever (struct File_spec *f, int nfiles)
 	  if (stats.st_size == f[i].size)
 	    {
 	      f[i].n_consecutive_size_changes = 0;
-	      if (++f[i].n_unchanged_stats > max_n_unchanged_stats_between_opens
+	      if ((max_n_unchanged_stats_between_opens
+		   <= f[i].n_unchanged_stats++)
 		  && follow_mode == Follow_name)
 		{
 		  recheck (&f[i]);
@@ -970,14 +972,11 @@ tail_forever (struct File_spec *f, int nfiles)
 	      continue;
 	    }
 
-	  /* Size changed.  */
-	  ++f[i].n_consecutive_size_changes;
-
 	  /* Ensure that a file that's unlinked or moved aside, yet always
 	     growing will be recognized as having been renamed.  */
-	  if (follow_mode == Follow_name
-	      && (f[i].n_consecutive_size_changes
-		  > max_n_consecutive_size_changes_between_opens))
+	  if ((max_n_consecutive_size_changes_between_opens
+	       <= f[i].n_consecutive_size_changes++)
+	      && follow_mode == Follow_name)
 	    {
 	      f[i].n_consecutive_size_changes = 0;
 	      recheck (&f[i]);
@@ -1130,7 +1129,10 @@ tail_lines (const char *pretty_filename, int fd, long int n_lines)
 
   if (from_start)
     {
-      if (start_lines (pretty_filename, fd, n_lines))
+      int t;
+      if ((t = start_lines (pretty_filename, fd, n_lines)) < 0)
+	return 0;
+      if (t)
 	return 1;
       dump_remainder (pretty_filename, fd, COPY_TO_EOF);
     }
@@ -1274,6 +1276,7 @@ parse_obsolescent_option (int argc, const char *const *argv,
   const char *p = argv[1];
   const char *n_string = NULL;
   const char *n_string_end;
+  bool obsolete_usage;
 
   int t_from_start;
   int t_count_lines;
@@ -1285,10 +1288,12 @@ parse_obsolescent_option (int argc, const char *const *argv,
   if (argc < 2)
     return 0;
 
+  obsolete_usage = (posix2_version () < 200112);
+
   /* If P starts with `+' and the POSIX version predates 1003.1-2001,
-     or P starts with `-N' (where N is a digit) or `-l',
-     then it is obsolescent.  Return zero otherwise.  */
-  if (! ((POSIX2_VERSION < 200112 && p[0] == '+')
+     or if P starts with `-N' (where N is a digit), or `-l', then it
+     is obsolescent.  Return zero otherwise.  */
+  if (! ((p[0] == '+' && obsolete_usage)
 	 || (p[0] == '-' && (p[1] == 'l' || ISDIGIT (p[1])))))
     return 0;
 
@@ -1353,13 +1358,13 @@ parse_obsolescent_option (int argc, const char *const *argv,
   else
     {
       strtol_error s_err;
-      unsigned long int tmp_ulong;
+      uintmax_t tmp;
       char *end;
 
-      s_err = xstrtoul (n_string, &end, 10, &tmp_ulong,
-			*n_string_end == 'b' ? "b" : NULL);
-      if (s_err == LONGINT_OK && tmp_ulong <= OFF_T_MAX)
-	*n_units = (off_t) tmp_ulong;
+      s_err = xstrtoumax (n_string, &end, 10, &tmp,
+			  *n_string_end == 'b' ? "b" : NULL);
+      if (s_err == LONGINT_OK && tmp <= OFF_T_MAX)
+	*n_units = (off_t) tmp;
       else
 	{
 	  /* Extract a NUL-terminated string for the error message.  */
@@ -1381,13 +1386,11 @@ parse_obsolescent_option (int argc, const char *const *argv,
 
   if (!*fail)
     {
-      bool posix_pedantic = (getenv ("POSIXLY_CORRECT") != NULL);
-
       if (argc > 3)
 	{
 	  /* When POSIXLY_CORRECT is set, enforce the `at most one
 	     file argument' requirement.  */
-	  if (posix_pedantic)
+	  if (getenv ("POSIXLY_CORRECT"))
 	    {
 	      error (0, 0, _("\
 too many arguments;  When using tail's obsolescent option syntax (%s)\n\
@@ -1405,10 +1408,13 @@ option instead."), argv[1]);
 #endif
 	}
 
-      if (! posix_pedantic)
-	error (0, 0,
-	       _("warning: `tail %s' is obsolete; use -n or -c instead"),
-	       argv[1]);
+      if (! obsolete_usage)
+	{
+	  error (0, 0, _("`%s' option is obsolete; use `%s-%c %.*s'"),
+		 argv[1], t_forever ? " -f" : "", t_count_lines ? 'n' : 'c',
+		 (int) (n_string_end - n_string), n_string);
+	  usage (EXIT_FAILURE);
+	}
 
       /* Set globals.  */
       from_start = t_from_start;
@@ -1592,12 +1598,11 @@ main (int argc, char **argv)
   have_read_stdin = 0;
 
   {
-    int found_obsolescent;
     int fail;
-    found_obsolescent = parse_obsolescent_option (argc,
-						  (const char *const *) argv,
-						  &n_units, &fail);
-    if (found_obsolescent)
+
+    if (parse_obsolescent_option (argc,
+				  (const char *const *) argv,
+				  &n_units, &fail))
       {
 	if (fail)
 	  exit (EXIT_FAILURE);
@@ -1610,8 +1615,8 @@ main (int argc, char **argv)
   }
 
   /* To start printing with item N_UNITS from the start of the file, skip
-     N_UNITS - 1 items.  `tail +0' is actually meaningless, but for Unix
-     compatibility it's treated the same as `tail +1'.  */
+     N_UNITS - 1 items.  `tail -n +0' is actually meaningless, but for Unix
+     compatibility it's treated the same as `tail -n +1'.  */
   if (from_start)
     {
       if (n_units)
