@@ -334,7 +334,9 @@ writing to standard output.\n\
 \n\
   -c, --complement        first complement SET1\n\
   -d, --delete            delete characters in SET1, do not translate\n\
-  -s, --squeeze-repeats   replace sequence of characters with one\n\
+  -s, --squeeze-repeats   replace each input sequence of a repeated character\n\
+                            that is listed in SET1 with a single occurrence\n\
+                            of that character\n\
   -t, --truncate-set1     first truncate SET1 to length of SET2\n\
 "), stdout);
       fputs (HELP_OPTION_DESCRIPTION, stdout);
@@ -391,7 +393,7 @@ only be used in pairs to specify case conversion.  \
 translating nor deleting; else squeezing uses SET2 and occurs after\n\
 translation or deletion.\n\
 "), stdout);
-      puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
@@ -545,7 +547,7 @@ unquote (const unsigned char *s, struct E_string *es)
 			}
 		      else if (!posix_pedantic)
 			{
-			  /* Any octal number larger than 0377 won't
+			  /* A 3-digit octal number larger than \377 won't
 			     fit in 8 bits.  So we stop when adding the
 			     next digit would put us over the limit and
 			     give a warning about the ambiguity.  POSIX
